@@ -90,9 +90,9 @@
 #define MSG_DELE_SUCCESS "Cancellato %s"
 #define MSG_DELE_TOTAL_FAILURE "Nessun file cancellato"
 #define MSG_LOAD_TOO_HIGH \
-	"Il carico era %3.2f quando ti sei connesso. Non permettiamo downloads\n" \
-	"da parte di utenti anonimi quando il carico  cos alto. Gli uploads sono sempre\n" \
-	"permessi."
+    "Il carico era %3.2f quando ti sei connesso. Non permettiamo downloads\n" \
+    "da parte di utenti anonimi quando il carico  cos alto. Gli uploads sono sempre\n" \
+    "permessi."
 #define MSG_OPEN_FAILURE "Impossibile aprire %s"
 #define MSG_OPEN_FAILURE2 "Impossibile aprire quel file"
 #define MSG_STAT_FAILURE "Impossibile trovare la dimensione del file"
@@ -101,12 +101,12 @@
 #define MSG_REST_RESET "Offset di ripartenza resettato a 0"
 #define MSG_NOT_REGULAR_FILE "Posso servire solo normali files"
 #define MSG_NOT_MODERATED \
-	"Questo file  stato uploadato da un utente anonimo. Non \n" \
-	"stato ancora approvato per il downloading dagli amministratore del sito."
+    "Questo file  stato uploadato da un utente anonimo. Non \n" \
+    "stato ancora approvato per il downloading dagli amministratore del sito."
 #define MSG_RATIO_DENIAL \
-	"Spiacente, ma la ratio di upload/download  %u:%u .\n" \
-	"Hai uploadato %llu Kb e downloadato %llu Kb.\n" \
-	"Per favore uploada un po' di roba e prova a scaricare pi tardi."
+    "Spiacente, ma la ratio di upload/download  %u:%u .\n" \
+    "Hai uploadato %llu Kb e downloadato %llu Kb.\n" \
+    "Per favore uploada un po' di roba e prova a scaricare pi tardi."
 #define MSG_NO_MORE_TO_DOWNLOAD "Niente altro da downloadare"
 #define MSG_WINNER "Il computer  tuo amico. Fidati del computer"
 #define MSG_KBYTES_LEFT "%.1f kbytes da downloadare"
@@ -205,7 +205,7 @@
 #define MSG_ILLEGAL_QUOTA "Quota non valida"
 #define MSG_QUOTA_FILES "%llu files usati (%d%%) - autorizzati: %llu files"
 #define MSG_QUOTA_SIZE "%llu Kbytes usati (%d%%) - autorizzati: %llu Kb"
-#define MSG_QUOTA_EXCEEDED "Quota superata : %s non verr salvato"
+#define MSG_QUOTA_EXCEEDED "Quota superata : [%s] non verr salvato"
 #define MSG_AUTH_UNKNOWN "Metodo di autenticazione sconosciuto"
 #define MSG_PDB_BROKEN "Impossibile leggere il file puredb indicizzato (o  stato trovato un vecchio formato) - Prova con pure-pw mkdb"
 #define MSG_ALIASES_ALIAS "%s  un alias per %s."
@@ -214,3 +214,15 @@
 #define MSG_ALIASES_LIST "Sono disponibili i seguenti aliases :"
 #define MSG_PERUSER_MAX "Non posso accettare pi di %lu connessioni dallo stesso utente"
 #define MSG_IPV6_OK "Anche le connessioni IPv6 sono benvenute su questo server"
+#define MSG_TLS_INFO "SSL/TLS: Abilitato %s con cifratura %s a %d bit"
+#define MSG_TLS_WEAK "SSL/TLS: Cifratura troppo debole"
+#define MSG_TLS_NEEDED "Spiacente, su questo server non sono ammesse sessioni in chiaro.\n" \
+    "Ricollegati usando i sistemi di sicurezza SSL/TLS."
+#define MSG_ILLEGAL_CHARSET "Illegal charset"
+#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
+#define MSG_PROT_OK "Data protection level set to \"%s\""
+#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
+#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
+#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
+#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
+#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
